@@ -1,6 +1,6 @@
 package Venus::Array;
 
-use 5.014;
+use 5.018;
 
 use strict;
 use warnings;
@@ -240,7 +240,7 @@ sub last {
 sub list {
   my ($self) = @_;
 
-  return (@{$self->value});
+  return wantarray ? (@{$self->value}) : scalar(@{$self->value});
 }
 
 sub map {
