@@ -359,10 +359,11 @@ Process Class for Perl 5
   my $process = $parent->fork;
 
   if ($process) {
-    # do something in forked process ...
+    # do something in child process ...
     $process->exit;
   }
   else {
+    # do something in parent process ...
     $parent->wait(-1);
   }
 
@@ -404,7 +405,7 @@ This package provides the following methods:
 
   chdir(Str $path) (Process)
 
-The chdir method changes the working directory the current process is opreting
+The chdir method changes the working directory the current process is operating
 within.
 
 I<Since C<0.06>>
@@ -415,9 +416,9 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  my $chdir = $parent->chdir;
+  $parent = $parent->chdir;
 
-  # 1
+  # bless({...}, 'Venus::Process')
 
 =back
 
@@ -427,9 +428,9 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  my $chdir = $parent->chdir('/tmp');
+  $parent = $parent->chdir('/tmp');
 
-  # 1
+  # bless({...}, 'Venus::Process')
 
 =back
 
@@ -439,7 +440,7 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  my $chdir = $parent->chdir('/xyz');
+  $parent = $parent->chdir('/xyz');
 
   # Exception!
 
@@ -451,8 +452,8 @@ I<Since C<0.06>>
 
   check(Int $pid) (Int, Int)
 
-The check method does a non-blocking L</waitpid> operation and returns the wait
-status. In list context, returns the specified process' exit code (if
+The check method does a non-blocking L<perlfunc/waitpid> operation and returns
+the wait status. In list context, returns the specified process' exit code (if
 terminated).
 
 I<Since C<0.06>>
@@ -470,7 +471,7 @@ I<Since C<0.06>>
   my ($process, $pid) = $parent->fork;
 
   if ($process) {
-    # do something in forked process ...
+    # in forked process ...
     $process->exit;
   }
 
@@ -493,7 +494,7 @@ I<Since C<0.06>>
   my ($process, $pid) = $parent->fork;
 
   if ($process) {
-    # do something in forked process ...
+    # in forked process ...
     $process->exit;
   }
 
@@ -513,12 +514,10 @@ I<Since C<0.06>>
 
   my $parent = Venus::Process->new;
 
-  my ($process, $pid) = $parent->fork(sub{
-    $_->exit(1);
-  });
+  my ($process, $pid) = $parent->fork(sub{ $_->exit(1) });
 
   if ($process) {
-    # do something in forked process ...
+    # in forked process ...
     $process->exit;
   }
 
@@ -536,7 +535,7 @@ I<Since C<0.06>>
 
 The daemon method detaches the process from controlling terminal and runs it in
 the background as system daemon. This method internally calls L</disengage> and
-L</setsid>, and attempts to change the working directory to the root directory.
+L</setsid> and attempts to change the working directory to the root directory.
 
 I<Since C<0.06>>
 
@@ -548,7 +547,7 @@ I<Since C<0.06>>
 
   my $daemon = $parent->daemon; # exits parent immediately
 
-  # do something in forked process ...
+  # in forked process ...
 
   # $daemon->exit;
 
@@ -562,8 +561,8 @@ I<Since C<0.06>>
 
 The disengage method limits the interactivity of the process by changing the
 working directory to the root directory and redirecting its standard file
-descriptors from and to /dev/null or the OS equivalent. These state changes can
-be undone by calling the L</engage> method.
+descriptors from and to C</dev/null>, or the OS' equivalent. These state
+changes can be undone by calling the L</engage> method.
 
 I<Since C<0.06>>
 
@@ -573,7 +572,7 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  $process = $parent->disengage;
+  $parent = $parent->disengage;
 
   # bless({...}, 'Venus::Process')
 
@@ -598,7 +597,7 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  $process = $parent->engage;
+  $parent = $parent->engage;
 
   # bless({...}, 'Venus::Process')
 
@@ -644,13 +643,13 @@ I<Since C<0.06>>
 
   fork(Str | CodeRef $code, Any @args) (Process, Int)
 
-The fork method calls the system L</fork> function and create a new process
-running the same program at the same point (or call site). This method return a
-newL<Venus::Process> object representing the child process within the child
-process (or fork), and returns C<undef> to the parent (or originating) process.
-In list context, this method returns both the process and I<PID> (or process
-ID) of the child process. If a callback or argument is provided it will be
-executed in the child process.
+The fork method calls the system L<perlfunc/fork> function and creates a new
+process running the same program at the same point (or call site). This method
+returns a new L<Venus::Process> object representing the child process (from
+within the execution of the child process (or fork)), and returns C<undef> to
+the parent (or originating) process. In list context, this method returns both
+the process and I<PID> (or process ID) of the child process. If a callback or
+argument is provided it will be executed in the child process.
 
 I<Since C<0.06>>
 
@@ -663,14 +662,16 @@ I<Since C<0.06>>
   $process = $parent->fork;
 
   # if ($process) {
-  #   # do something in forked process ...
+  #   # in forked process ...
   #   $process->exit;
   # }
   # else {
-  #   # do something in the parent process ...
+  #   # in parent process ...
   #   $parent->wait(-1);
   # }
 
+  # in child process
+
   # bless({...}, 'Venus::Process')
 
 =back
@@ -686,15 +687,17 @@ I<Since C<0.06>>
   ($process, $pid) = $parent->fork;
 
   # if ($process) {
-  #   # do something in forked process ...
+  #   # in forked process ...
   #   $process->exit;
   # }
   # else {
-  #   # do something in the parent process ...
+  #   # in parent process ...
   #   $parent->wait($pid);
   # }
 
-  # bless({...}, 'Venus::Process')
+  # in parent process
+
+  # (undef, $pid)
 
 =back
 
@@ -711,15 +714,17 @@ I<Since C<0.06>>
   });
 
   # if ($process) {
-  #   # do something in forked process ...
+  #   # in forked process ...
   #   $process->exit;
   # }
   # else {
-  #   # do something in the parent process ...
+  #   # in parent process ...
   #   $parent->wait($pid);
   # }
 
-  # bless({...}, 'Venus::Process')
+  # in parent process
+
+  # (undef, $pid)
 
 =back
 
@@ -729,14 +734,14 @@ I<Since C<0.06>>
 
   forks(Str | CodeRef $code, Any @args) (Process, ArrayRef[Int])
 
-The forks method creates multiple forks by calling the L</fork> method "n"
-times based on the count specified. As with the singular L</fork> method, this
-method return a new L<Venus::Process> object representing the child process
-within the child process (or fork), and returns C<undef> to the parent (or
-originating) process. In list context, this method returns both the process
-and an arrayref of I<PID> values (or process IDs) for each of the child
-processes created. If a callback or argument is provided it will be executed in
-each child process.
+The forks method creates multiple forks by calling the L</fork> method C<n>
+times, based on the count specified. As with the L</fork> method, this method
+returns a new L<Venus::Process> object representing the child process (from
+within the execution of the child process (or fork)), and returns C<undef> to
+the parent (or originating) process. In list context, this method returns both
+the process and an arrayref of I<PID> values (or process IDs) for each of the
+child processes created. If a callback or argument is provided it will be
+executed in each child process.
 
 I<Since C<0.06>>
 
@@ -753,7 +758,7 @@ I<Since C<0.06>>
   #   $process->exit;
   # }
   # else {
-  #   # do something in the parent process ...
+  #   # do something in parent process ...
   #   $parent->wait(-1);
   # }
 
@@ -776,11 +781,11 @@ I<Since C<0.06>>
   #   $process->exit;
   # }
   # else {
-  #   # do something in the parent process ...
+  #   # do something in parent process ...
   #   $parent->wait($_) for @$pids;
   # }
 
-  # in the parent process
+  # in parent process
 
   # (undef, $pids)
 
@@ -805,11 +810,11 @@ I<Since C<0.06>>
   #   $process->exit;
   # }
   # else {
-  #   # do something in the parent process ...
+  #   # do something in parent process ...
   #   $parent->wait($_) for @$pids;
   # }
 
-  # in the child process
+  # in child process
 
   # bless({...}, 'Venus::Process')
 
@@ -821,9 +826,9 @@ I<Since C<0.06>>
 
   kill(Str $signal, Int @pids) (Int)
 
-The kill method calls the system L</kill> function which sends a signal to a
-list of processes and returns truthy or falsy. B<Note:> A truthy result doesn't
-necessarily mean all processes were successfully signalled.
+The kill method calls the system L<perlfunc/kill> function which sends a signal
+to a list of processes and returns truthy or falsy. B<Note:> A truthy result
+doesn't necessarily mean all processes were successfully signalled.
 
 I<Since C<0.06>>
 
@@ -834,11 +839,11 @@ I<Since C<0.06>>
   # given: synopsis;
 
   if ($process = $parent->fork) {
-    # do something in forked process ...
+    # in forked process ...
     $process->exit;
   }
 
-  my $kill = $parent->kill('term', $process->value);
+  my $kill = $parent->kill('term', int$process);
 
   # 1
 
@@ -885,7 +890,7 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  $process = $parent->stderr;
+  $parent = $parent->stderr;
 
   # bless({...}, 'Venus::Process')
 
@@ -909,7 +914,7 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  $process = $parent->stdin;
+  $parent = $parent->stdin;
 
   # bless({...}, 'Venus::Process')
 
@@ -933,7 +938,7 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  $process = $parent->stdout;
+  $parent = $parent->stdout;
 
   # bless({...}, 'Venus::Process')
 
@@ -975,7 +980,7 @@ I<Since C<0.06>>
   untrap(Str $name) (Process)
 
 The untrap method restores the process signal trap specified to its default
-behavior. If called with no arguments, restores all signal traps overwriting
+behavior. If called with no arguments, it restores all signal traps overwriting
 any user-defined signal traps in the current process.
 
 I<Since C<0.06>>
@@ -986,9 +991,7 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  $parent->trap(chld => 'ignore');
-
-  $parent->trap(term => sub{
+  $parent->trap(chld => 'ignore')->trap(term => sub{
     die 'Something failed!';
   });
 
@@ -1004,9 +1007,7 @@ I<Since C<0.06>>
 
   # given: synopsis;
 
-  $parent->trap(chld => 'ignore');
-
-  $parent->trap(term => sub{
+  $parent->trap(chld => 'ignore')->trap(term => sub{
     die 'Something failed!';
   });
 
@@ -1022,8 +1023,8 @@ I<Since C<0.06>>
 
   wait(Int $pid) (Int, Int)
 
-The wait method does a blocking L</waitpid> operation and returns the wait
-status. In list context, returns the specified process' exit code (if
+The wait method does a blocking L<perlfunc/waitpid> operation and returns the
+wait status. In list context, returns the specified process' exit code (if
 terminated).
 
 I<Since C<0.06>>
@@ -1041,11 +1042,11 @@ I<Since C<0.06>>
   my ($process, $pid) = $parent->fork;
 
   if ($process) {
-    # do something in forked process ...
+    # in forked process ...
     $process->exit;
   }
 
-  my $check = $parent->wait($pid);
+  my $wait = $parent->wait($pid);
 
   # 0
 
@@ -1064,11 +1065,11 @@ I<Since C<0.06>>
   my ($process, $pid) = $parent->fork;
 
   if ($process) {
-    # do something in forked process ...
+    # in forked process ...
     $process->exit;
   }
 
-  my ($check, $status) = $parent->wait('00000');
+  my ($wait, $status) = $parent->wait('00000');
 
   # (-1, -1)
 
@@ -1084,16 +1085,14 @@ I<Since C<0.06>>
 
   my $parent = Venus::Process->new;
 
-  my ($process, $pid) = $parent->fork(sub{
-    $_->exit(1);
-  });
+  my ($process, $pid) = $parent->fork(sub{ $_->exit(1) });
 
   if ($process) {
-    # do something in forked process ...
+    # in forked process ...
     $process->exit;
   }
 
-  my ($check, $status) = $parent->wait($pid);
+  my ($wait, $status) = $parent->wait($pid);
 
   # ($pid, 1)
 
@@ -1107,9 +1106,9 @@ I<Since C<0.06>>
 
 The work method forks the current process, runs the callback provided in the
 child process, and immediately exits after. This method returns the I<PID> of
-the child process. It is recommended to install an L</alarm> in the child
-process (i.e. callback) to avoid creating zombie processed in situations where
-the parent process might exit before the child process is done working.
+the child process. It is recommended to install an L<perlfunc/alarm> in the
+child process (i.e. callback) to avoid creating zombie processes in situations
+where the parent process might exit before the child process is done working.
 
 I<Since C<0.06>>
 
@@ -1121,7 +1120,7 @@ I<Since C<0.06>>
 
   my $pid = $parent->work(sub{
     my ($process) = @_;
-    # do something in forked process ...
+    # in forked process ...
     $process->exit;
   });
 
