@@ -1,6 +1,6 @@
 package Venus::String;
 
-use 5.014;
+use 5.018;
 
 use strict;
 use warnings;
@@ -21,9 +21,15 @@ use overload (
 sub append {
   my ($self, @args) = @_;
 
+  return $self->append_with(' ', @args);
+}
+
+sub append_with {
+  my ($self, $delimiter, @args) = @_;
+
   my $data = $self->get;
 
-  return CORE::join(' ', $data, @args);
+  return CORE::join($delimiter // '', $data, @args);
 }
 
 sub camelcase {
@@ -142,6 +148,28 @@ sub lowercase {
   return CORE::lc($data);
 }
 
+sub prepend {
+  my ($self, @args) = @_;
+
+  return $self->prepend_with(' ', @args);
+}
+
+sub prepend_with {
+  my ($self, $delimiter, @args) = @_;
+
+  my $data = $self->get;
+
+  return CORE::join($delimiter // '', @args, $data);
+}
+
+sub repeat {
+  my ($self, $count, $delimiter) = @_;
+
+  my $data = $self->get;
+
+  return CORE::join($delimiter // '', CORE::map $data, 1..($count || 1));
+}
+
 sub render {
   my ($self, $tokens) = @_;
 
@@ -150,9 +178,9 @@ sub render {
   $tokens ||= {};
 
   while (my($key, $value) = each(%$tokens)) {
-    my $token = quotemeta "{$key}";
+    my $token = quotemeta $key;
 
-    $data =~ s/$token/$value/g;
+    $data =~ s/\{\{\s*$token\s*\}\}/$value/g;
   }
 
   return $data;
@@ -228,6 +256,21 @@ sub strip {
   return $data;
 }
 
+sub substr {
+  my ($self, $offset, $length, $replace) = @_;
+
+  my $data = $self->get;
+
+  if (CORE::defined($replace)) {
+    my $result = CORE::substr($data, $offset // 0, $length // 0, $replace);
+    return wantarray ? ($result, $data) : $data;
+  }
+  else {
+    my $result = CORE::substr($data, $offset // 0, $length // 0);
+    return wantarray ? ($result, $data) : $result;
+  }
+}
+
 sub titlecase {
   my ($self) = @_;
 
@@ -334,9 +377,6 @@ This package provides the following methods:
 
 The append method appends arugments to the string using spaces.
 
-
-
-
 I<Since C<0.01>>
 
 =over 4
@@ -793,7 +833,7 @@ I<Since C<0.01>>
 
   use Venus::String;
 
-  my $string = Venus::String->new('Hi, {name}!');
+  my $string = Venus::String->new('Hi, {{name}}!');
 
   my $render = $string->render({name => 'Friend'});
 
